@@ -57,8 +57,8 @@ oper_spectra <- function(w.length1, w.length2 = NULL,
   if (is.null(w.length2) ||
       (length(w.length1) == length(w.length2) && all(w.length1 == w.length2))) {
     # we can skip interpolation
-    if (length(s.irrad1) == length(s.irrad2) &
-          length(w.length1) == length(s.irrad1)){
+    if (length(s.irrad1) == length(s.irrad2) &&
+          length(w.length1) == length(s.irrad1)) {
       s.irrad.result <- bin.oper(s.irrad1, s.irrad2, ...)
       w.length <- w.length1
     } else {
@@ -66,7 +66,7 @@ oper_spectra <- function(w.length1, w.length2 = NULL,
     }
     return(invisible(tibble::tibble(w.length, s.irrad = s.irrad.result)))
   }
-  if (length(w.length2) != length(s.irrad2) |
+  if (length(w.length2) != length(s.irrad2) ||
         length(w.length1) != length(s.irrad1)){
     stop("Mismatch in the length of input vectors")
   } else if (trim == "union") {
