@@ -4,13 +4,13 @@
 #' spectral values are calculated by interpolation. After this, the two spectral
 #' values at each wavelength are added.
 #'
-#' @param w.length1 numeric array of wavelength (nm)
-#' @param w.length2 numeric array of wavelength (nm)
-#' @param s.irrad1 a numeric array of spectral values
-#' @param s.irrad2 a numeric array of spectral values
-#' @param trim a character string with value "union" or "intersection"
+#' @param w.length1 numeric vector of wavelength (nm).
+#' @param w.length2 numeric vector of wavelength (nm).
+#' @param s.irrad1 a numeric vector of spectral values.
+#' @param s.irrad2 a numeric vector of spectral values.
+#' @param trim a character string with value "union" or "intersection".
 #' @param na.rm a logical value, if TRUE, not the default, NAs in the input are
-#'   replaced with zeros
+#'   replaced with zeros.
 #'
 #' @return a dataframe with two numeric variables \item{w.length}{A numeric
 #'   vector with the wavelengths (nm) obtained by "fusing" w.length1 and
@@ -21,22 +21,27 @@
 #'   of wavelengths covered by at least one of the input spectra, and missing
 #'   values are set in each input spectrum to zero before addition. If
 #'   trim=="intersection" then the range of wavelengths covered by both input
-#'   spectra is returned, and the non-overlaping regions discarded. If
+#'   spectra is returned, and the non-overlapping regions discarded. If
 #'   w.length2==NULL, it is assumed that both spectra are measured at the same
 #'   wavelengths, and a simple addition is used, ensuring fast calculation.
 #' @export
 #'
 #' @examples
-#' 
+#'
 #' head(sun.data)
 #' square.sun.data <-
 #'   with(sun.data, prod_spectra(w.length, w.length, s.e.irrad, s.e.irrad))
 #' head(square.sun.data)
 #' tail(square.sun.data)
 #'
-prod_spectra <- function(w.length1, w.length2=NULL, s.irrad1, s.irrad2, trim="union", na.rm=FALSE) {
-  return(oper_spectra(w.length1=w.length1, w.length2=w.length2,
-                      s.irrad1=s.irrad1, s.irrad2=s.irrad2,
-                      trim="union", na.rm=FALSE,
-                      bin.oper=`*`))
-}
+#' @family low-level functions operating on numeric vectors.
+#'
+prod_spectra <-
+  function(w.length1, w.length2 = NULL,
+           s.irrad1, s.irrad2,
+           trim = "union", na.rm = FALSE) {
+    return(oper_spectra(w.length1 = w.length1, w.length2 = w.length2,
+                        s.irrad1 = s.irrad1, s.irrad2 = s.irrad2,
+                        trim = "union", na.rm = FALSE,
+                        bin.oper = `*`))
+  }
