@@ -65,6 +65,23 @@ transmittance.filter_spct <-
            use.hinges = NULL,
            naming = "default",
            ...) {
+
+    # we look for multiple spectra in long form
+    if (getMultipleWl(spct) > 1) {
+      # convert to a collection of spectra
+      mspct <- subset2mspct(x = spct,
+                            idx.var = getIdFactor(spct),
+                            drop.idx = FALSE)
+      # call method on the collection
+      return(transmittance(spct = mspct,
+                           w.band = w.band,
+                           quantity = quantity,
+                           wb.trim = wb.trim,
+                           use.hinges = use.hinges,
+                           naming = naming,
+                           ...))
+    }
+
     transmittance_spct(spct = spct,
                        w.band = w.band,
                        quantity = quantity,
@@ -84,6 +101,23 @@ transmittance.object_spct <-
            use.hinges = NULL,
            naming = "default",
            ...) {
+
+    # we look for multiple spectra in long form
+    if (getMultipleWl(spct) > 1) {
+      # convert to a collection of spectra
+      mspct <- subset2mspct(x = spct,
+                            idx.var = getIdFactor(spct),
+                            drop.idx = FALSE)
+      # call method on the collection
+      return(transmittance(spct = mspct,
+                           w.band = w.band,
+                           quantity = quantity,
+                           wb.trim = wb.trim,
+                           use.hinges = use.hinges,
+                           naming = naming,
+                           ...))
+    }
+
     transmittance_spct(spct = spct,
                        w.band = w.band,
                        quantity = quantity,
@@ -128,24 +162,6 @@ transmittance_spct <-
            naming,
            ...) {
 
-    # we look for multiple spectra
-    num.spectra <- getMultipleWl(spct)
-    if (num.spectra != 1) {
-      message("Object contains ", num.spectra, " spectra in long form")
-      # convert to a collection of spectra
-      mspct <- subset2mspct(x = spct,
-                            idx.var = getIdFactor(spct),
-                            drop.idx = FALSE)
-      # call method on the collection
-      return(transmittance(spct = mspct,
-                           w.band = w.band,
-                           quantity = quantity,
-                           wb.trim = wb.trim,
-                           use.hinges = use.hinges,
-                           naming,
-                           ...))
-    }
-
     summary.name <-
       switch(quantity,
              total = "Tfr",
@@ -296,6 +312,9 @@ transmittance.filter_mspct <-
            ...,
            attr2tb = NULL,
            idx = "spct.idx") {
+
+    spct <- subset2mspct(spct) # expand long form spectra within collection
+
     z <-
       msdply(
         mspct = spct,
@@ -338,6 +357,9 @@ transmittance.object_mspct <-
            idx = "spct.idx",
            .parallel = FALSE,
            .paropts = NULL) {
+
+    spct <- subset2mspct(spct) # expand long form spectra within collection
+
     z <-
       msdply(
         mspct = spct,
@@ -352,6 +374,7 @@ transmittance.object_mspct <-
         .parallel = .parallel,
         .paropts = .paropts
       )
+
     add_attr2tb(tb = z,
                 mspct = spct,
                 col.names = attr2tb,
