@@ -47,13 +47,15 @@
 #' @family trim functions
 #' @export
 #' @examples
-#' VIS <- waveband(c(380, 760)) # manometers
+#' VIS <- waveband(c(380, 760)) # nanometres
 #'
-#' trim_waveband(VIS, c(400,700))
+#' trim_waveband(VIS, c(400, 700))
+#' trim_waveband(VIS, c(NA, 700))
+#' trim_waveband(VIS, c(400, NA))
 #' trim_waveband(VIS, low.limit = 400)
 #' trim_waveband(VIS, high.limit = 700)
-#' trim_waveband(VIS, c(400,700), trunc.labels = c(">", "<"))
-#' trim_waveband(VIS, c(400,700), trunc.labels = "!")
+#' trim_waveband(VIS, c(400, 700), trunc.labels = c(">", "<"))
+#' trim_waveband(VIS, c(400, 700), trunc.labels = "!")
 #'
 trim_waveband <-
   function(w.band,
@@ -112,14 +114,22 @@ trim_waveband <-
             if (length(trunc.labels) == 1L) {
               trunc.labels <- rep(trunc.labels, 2L)
             }
-            trimmed.wb[["label"]] <-
-              paste(ifelse(trimmed.low, trunc.labels[1], ""),
-                    wb[["label"]],
-                    ifelse(trimmed.high, trunc.labels[2], ""), sep = "")
-            trimmed.wb[["name"]] <-
-              paste(ifelse(trimmed.low, trunc.labels[1], ""),
-                    wb[["name"]],
-                    ifelse(trimmed.high, trunc.labels[2], ""), sep = "")
+            trimmed.wb[["label"]] <- wb[["label"]]
+            trimmed.wb[["name"]] <- wb[["name"]]
+            if (trimmed.low &&
+                !startsWith(trimmed.wb[["label"]], trunc.labels[1])) {
+              trimmed.wb[["label"]] <-
+                paste(trunc.labels[1], trimmed.wb[["label"]], sep = "")
+              trimmed.wb[["name"]] <-
+                paste(trunc.labels[1], trimmed.wb[["name"]], sep = "")
+            }
+            if (trimmed.high &&
+                !endsWith(trimmed.wb[["label"]], trunc.labels[2])) {
+              trimmed.wb[["label"]] <-
+                paste(trimmed.wb[["label"]], trunc.labels[2], sep = "")
+              trimmed.wb[["name"]] <-
+                paste(trimmed.wb[["name"]], trunc.labels[2], sep = "")
+            }
           } else {
             trimmed.tag <-  paste("tr", ifelse(trimmed.low, ".lo", ""),
                                   ifelse(trimmed.high, ".hi", ""), sep = "")
